==> language-env_0.38.tar.gz: language-env-0.38/support.pl.pl <==
# !Polski,Polish! -*-coding: iso-8859-2;-*-
#
# Polish support by Robert Luberda <robert@pingu.ii.uj.edu.pl>, Jul 2001

# ---------------------------------------------------
sub isNC($$$)
{
	my $reply;
        print STDERR "\n         \n";
        print STDERR "Czy widzisz polskie znaki w linii powyzej? [t/N] ";
        $reply = <>;
        if ($reply =~ /t|T/) {
                return 1;
        }
        return 0;

}

# ---------------------------------------------------
sub initialize()
{
	&Sub::addlist("locales");
	&Sub::addlist("fonty");

# manpages
	&Sub::addlist("manpages-pl");
	if (&Sub::isinstalled("manpages-dev")) {
		&Sub::addlist("manpages-pl-dev");
	}

# linux-doc
	if (&Sub::isinstalled("doc-linux-html")) {
		&Sub::addlist("doc-linux-html-pl");
	}
	if (&Sub::isinstalled("doc-linux-text")) {
		&Sub::addlist("doc-linux-text-pl");
	}

# x-fonts
	if (&Sub::isinstalled("xserver-.*")) {
		&Sub::addlist("xfonts-biznet-iso-8859-2-base");
		&Sub::addlist("xfonts-biznet-iso-8859-2-75dpi");
		&Sub::addlist("xfonts-biznet-iso-8859-2-100dpi");
	}
 
	
	return 0;
}


# ---------------------------------------------------
sub sourceset2displayset ($)
{
	return $_[0];
}


# ---------------------------------------------------
sub analcode($)
{
	return 0;
}


# ---------------------------------------------------
sub convcode($$)
{
	return $_[0];
}


# ---------------------------------------------------
%messages = (

# msgid
  "\nPush [Enter] key to End.\n" =>
# msgstr1 (in native language but in ASCII)
  "\nNacisnij [Enter], aby zakonczyc.\n\000".
# msgstr2 (in native language and in native character set: for
# example ISO-8859-1)
  "\nNacinij [Enter], aby zakoczy.\n" ,

# msgid
  "Now obtaining package list...\n" =>
  "Trwa pobieranie listy pakietow...\n\000".
  "Trwa pobieranie listy pakietw...\n" ,

# msgid
  "Do setting? " =>
  "Ustawic? \000".
  "Ustawi? " ,

# msgid
  "Setting is not done.\n" =>
  "Nie ustawiono.\n\000".
  "Nie ustawiono.\n" ,

# msgid
  "Do setting...\n" =>
  "Zapisywanie ustawienia...\n\000".
  "Zapisywanie ustawienia...\n" ,

# msgid
  "Cannot read \"%s\".\n" =>
  "Nie mozna czytac \"%s\".\n\000".
  "Nie mona czyta \"%s\".\n" ,

# msgid
  "Making a new file \"%s\"...\n" =>
  "Tworzenie nowego pliku \"%s\"...\n\000".
  "Tworzenie nowego pliku \"%s\"...\n" ,

# msgid
  "Cannot open \"%s\".\n" =>
  "Nie mozna otworzyc \"%s\".\n\000".
  "Nie mona otworzy \"%s\".\n" ,

# msgid
  "Cannot write to \"%s\".\n" =>
  "Nie mozna zapisywac do \"%s\".\n\000".
  "Nie mona zapisywa do \"%s\".\n" ,

# msgid
  "Cannot lock \"%s\".\n" =>
  "Nie mozna zablokowac \"%s\".\n\000".
  "Nie mona zablokowa \"%s\".\n" ,

# msgid
  "Cannot close \"%s\".\n" =>
  "Nie mozna zamknac \"%s\".\n\000".
  "Nie mona zamkn \"%s\".\n" ,

# msgid
  "Install the following packages.\n" =>
# msgstr1 (ASCII)
  "Prosze zainstalowac nastepujace pakiety.\n\000".
# msgstr2 (in Native Character Set)
  "Prosz zainstalowa nastpujce pakiety.\n" ,

# msgid
  "   Setting is now done.  To activate these settings,\n".
  "logout and login.\n".
  "   Read each dotfile and confirm the modification.\n".
  "If you don't like the setting, modify directly or\n".
  "add overriding setting after 'language-env end' line.\n".
  "   Read /usr/share/doc/language-env/README.* for detail.\n" =>
# msgstr1 (ASCII)
  "   Zapisano ustawienia.  Aby je uaktywnic, nalezy sie\n".
  "wylogowac i zalogowac ponownie\n.\n".
  "   Prosze przejrzec kazdy zmieniony plik konfiguracyjny i sprawdzic\n".
  "ustawienia. Jezeli nie sa one zgodne z Twoimi oczekiwaniami, \n".
  "popraw je lub dodaj wlasne nadpisujace ustawienie po linii 'language-env end'.\n".
  "   Szczegolowe informacje mozna znalezc w /usr/share/doc/language-env/README.* .\n\000" .
# msgstr2 (in Native Character Set)
  "   Zapisano ustawienia.  Aby je uaktywni, naley si\n".
  "wylogowa i zalogowa ponownie\n.\n".
  "   Prosz przejrze kady zmieniony plik konfiguracyjny i sprawdzi\n".
  "ustawienia. Jeeli nie s one zgodne z Twoimi oczekiwaniami, \n".
  "popraw je lub dodaj wasne nadpisujce ustawienie po linii 'language-env end'.\n".
  "   Szczegowe informacje mona znale w /usr/share/doc/language-env/README.* .\n" ,

# msgid
  "Usage: set-language-env [options]\n".
  "  -l language : Specify language (otherwise choose from menu)\n".
  "  -h          : This help message\n".
  "  -v          : 'verbose mode'\n".
  "  -s          : Display list of supported languages and exit\n".
  "  -r          : Remove all settings\n".
  "  -N          : Never fork another set-language-env (for internal use)\n".
  "  -c          : Don't use native character set (for internal use)\n".
  "  -C          : Use native character set (for internal use)\n".
  "  -E          : Setting for /etc/skel directory (root user only)\n" =>
# msgstr1 (ASCII)
  "Uzycie: set-language-env [opcje]\n".
  "  -l jezyk    : Okresla jezyk (jezeli nie podano, to wybor z menu)\n".
  "  -h          : Ten komunikat pomocy\n".
  "  -v          : Tryb gadatliwy\n".
  "  -s          : Wyswietla liste wspieranych jezykow i konczy dzialanie\n".
  "  -r          : Usuwa wszystkie ustawienia\n".
  "  -N          : Nie forkuje set-language-env (do uzytku wewnetrznego)\n".
  "  -c          : Nie uzywa natywnego zestawu znakow (do uzytku wewnetrz.)\n".
  "  -C          : Uzywa natywnego zestawu znakow (do uzytku wewnetrznego)\n".
  "  -E          : Ustawienia w katalogu /etc/skel (tylko uzytkownik root)\n\000" .
# msgstr2 (in Native Character Set)
  "Uycie: set-language-env [opcje]\n".
  "  -l jzyk    : Okrela jzyk (jeeli nie podano, to wybr z menu)\n".
  "  -h          : Ten komunikat pomocy\n".
  "  -v          : Tryb gadatliwy\n".
  "  -s          : Wywietla list wspieranych jzykw i koczy dziaanie\n".
  "  -r          : Usuwa wszystkie ustawienia\n".
  "  -N          : Nie forkuje set-language-env (do uytku wewntrznego)\n".
  "  -c          : Nie uywa natywnego zestawu znakw (do uytku wewntrz.)\n".
  "  -C          : Uywa natywnego zestawu znakw (do uytku wewntrznego)\n".
  "  -E          : Ustawienia w katalogu /etc/skel (tylko uytkownik root)\n" ,

# msgid
  "Install the following locales.\n" =>
  "Prosze zainstalowac nastepujace definicje ustawien regionalnych.\n\000".
  "Prosz zainstalowa nastpujce definicje ustawie regionalnych.\n" ,

# msgid
  "(Edit /etc/locale.gen and invoke locale-gen)\n" =>
  "(Wyedytuj /etc/locale.gen, a nastepnie uruchom locale-gen)\n\000".
  "(Wyedytuj /etc/locale.gen, a nastpnie uruchom locale-gen)\n" ,

# msgid
  "" =>
  "\000".
  ""

);

$yes_upper = "T";
$yes_lower = "t";
$no_upper  = "N";
$no_lower  = "n";
$need_locale = 'pl_PL.ISO-8859-2(pl_PL.ISO-8859-2 ISO-8859-2)';

==> language-env_0.58.tar.gz: language-env-0.58/support.pl.pl <==
# !Polski,Polish! -*-coding: iso-8859-2;-*-
#
# Polish support by Robert Luberda <robert@debian.org>, Jul 2001
# Updated: Robert Luberda, Apr 2004

# ---------------------------------------------------
sub isNC($$$)
{
	my $reply;
        print STDERR "\n         \n";
        print STDERR "Czy widzisz polskie znaki w linii powyzej? [t/N] ";
        $reply = <STDIN>;
        if ($reply =~ /t|T/) {
                return 1;
        }
        return 0;

}

# ---------------------------------------------------
sub initialize()
{
	&Sub::addlist("locales");
	&Sub::addlist("fonty");

# manpages
	&Sub::addlist("manpages-pl");
	if (&Sub::isinstalled("manpages-dev")) {
		&Sub::addlist("manpages-pl-dev");
	}

# fortunes
	if (&Sub::isinstalled("fortune-mod")) {
		&Sub::addlist("fortunes-pl");
	}

# linux-doc
	if (&Sub::isinstalled("doc-linux-html")) {
		&Sub::addlist("doc-linux-pl-html");
	}
	if (&Sub::isinstalled("doc-linux-text")) {
		&Sub::addlist("doc-linux-pl");
	}

# ispell
        if (&Sub::isinstalled("ispell")) {
                &Sub::addlist("ipolish");
                &Sub::addlist("wpolish");
	}

# aspell
	if (&Sub::isinstalled("libaspell.*")) {
		&Sub::addlist("aspell-pl");
	}

# openoffice
	if (&Sub::isinstalled("openoffice.org")) {
		&Sub::addlist("openoffice.org-l10n-pl");
		&Sub::addlist("myspell-pl");
	}

# mozilla
	if (&Sub::isinstalled("mozilla-browser")) {
		&Sub::addlist("mozilla-locale-pl");
		&Sub::addlist("myspell-pl");
	}
# kde
        if (&Sub::isinstalled("kdebase")) {
                &Sub::addlist("kde-i18n-pl");
	}
# koffice
        if (&Sub::isinstalled("koffice")) {
                &Sub::addlist("koffice-i18n-pl");
	}
# xterm (luit)
        if (&Sub::isinstalled("xterm")) {
                &Sub::addlist("xutils");
	}


# x-fonts
	if (&Sub::isinstalled("xserver-.*")) {
		&Sub::addlist("xfonts-biznet-base");
		&Sub::addlist("xfonts-base-transcoded");
		if (&Sub::isinstalled("xfonts-75dpi")) {
			&Sub::addlist("xfonts-biznet-75dpi");
			&Sub::addlist("xfonts-75dpi-transcoded");
		}
		if (&Sub::isinstalled("xfonts-100dpi")) {
			&Sub::addlist("xfonts-biznet-100dpi");
			&Sub::addlist("xfonts-100dpi-transcoded");
		}
	}
 
	
	return 0;
}


# ---------------------------------------------------
sub sourceset2displayset ($)
{
	return $_[0];
}


# ---------------------------------------------------
sub analcode($)
{
	return 0;
}


# ---------------------------------------------------
sub convcode($$)
{
	return $_[0];
}


# ---------------------------------------------------
%messages = (

# msgid
  "\nPush [Enter] key to End.\n" =>
# msgstr1 (in native language but in ASCII)
  "\nNacisnij [Enter], aby zakonczyc.\n\000".
# msgstr2 (in native language and in native character set: for
# example ISO-8859-1)
  "\nNacinij [Enter], aby zakoczy.\n" ,

# msgid
  "Now obtaining package list...\n" =>
  "Trwa pobieranie listy pakietow...\n\000".
  "Trwa pobieranie listy pakietw...\n" ,

# msgid
  "Do setting? " =>
  "Ustawic? \000".
  "Ustawi? " ,

# msgid
  "Setting is not done.\n" =>
  "Nie ustawiono.\n\000".
  "Nie ustawiono.\n" ,

# msgid
  "Do setting...\n" =>
  "Zapisywanie ustawienia...\n\000".
  "Zapisywanie ustawienia...\n" ,

# msgid
  "Cannot read \"%s\".\n" =>
  "Nie mozna czytac \"%s\".\n\000".
  "Nie mona czyta \"%s\".\n" ,

# msgid
  "Making a new file \"%s\"...\n" =>
  "Tworzenie nowego pliku \"%s\"...\n\000".
  "Tworzenie nowego pliku \"%s\"...\n" ,

# msgid
  "Cannot open \"%s\".\n" =>
  "Nie mozna otworzyc \"%s\".\n\000".
  "Nie mona otworzy \"%s\".\n" ,

# msgid
  "Cannot write to \"%s\".\n" =>
  "Nie mozna zapisywac do \"%s\".\n\000".
  "Nie mona zapisywa do \"%s\".\n" ,

# msgid
  "Cannot lock \"%s\".\n" =>
  "Nie mozna zablokowac \"%s\".\n\000".
  "Nie mona zablokowa \"%s\".\n" ,

# msgid
  "Cannot close \"%s\".\n" =>
  "Nie mozna zamknac \"%s\".\n\000".
  "Nie mona zamkn \"%s\".\n" ,

# msgid
  "Install the following packages.\n" =>
# msgstr1 (ASCII)
  "Prosze zainstalowac nastepujace pakiety.\n\000".
# msgstr2 (in Native Character Set)
  "Prosz zainstalowa nastpujce pakiety.\n" ,

# msgid
  "   Setting is now done.  To activate these settings,\n".
  "logout and login.\n".
  "   Read each dotfile and confirm the modification.\n".
  "If you don't like the setting, modify directly or\n".
  "add overriding setting after 'language-env end' line.\n".
  "   Read /usr/share/doc/language-env/README.* for detail.\n" =>
# msgstr1 (ASCII)
  "   Zapisano ustawienia.  Aby je uaktywnic, nalezy sie\n".
  "wylogowac i zalogowac ponownie\n.\n".
  "   Prosze przejrzec kazdy zmieniony plik konfiguracyjny i sprawdzic\n".
  "ustawienia. Jezeli nie sa one zgodne z Twoimi oczekiwaniami, \n".
  "popraw je lub dodaj wlasne nadpisujace ustawienie po linii 'language-env end'.\n".
  "   Szczegolowe informacje mozna znalezc w /usr/share/doc/language-env/README.* .\n\000" .
# msgstr2 (in Native Character Set)
  "   Zapisano ustawienia.  Aby je uaktywni, naley si\n".
  "wylogowa i zalogowa ponownie\n.\n".
  "   Prosz przejrze kady zmieniony plik konfiguracyjny i sprawdzi\n".
  "ustawienia. Jeeli nie s one zgodne z Twoimi oczekiwaniami, \n".
  "popraw je lub dodaj wasne nadpisujce ustawienie po linii 'language-env end'.\n".
  "   Szczegowe informacje mona znale w /usr/share/doc/language-env/README.* .\n" ,

# msgid
  "Usage: set-language-env [options]\n".
  "  -l language : Specify language (otherwise choose from menu)\n".
  "  -h          : This help message\n".
  "  -v          : 'verbose mode'\n".
  "  -s          : Display list of supported languages and exit\n".
  "  -r          : Remove all settings\n".
  "  -N          : Never fork another set-language-env (for internal use)\n".
  "  -c          : Don't use native character set (for internal use)\n".
  "  -C          : Use native character set (for internal use)\n".
  "  -E          : Setting for /etc/skel directory (root user only)\n" =>
# msgstr1 (ASCII)
  "Uzycie: set-language-env [opcje]\n".
  "  -l jezyk    : Okresla jezyk (jezeli nie podano, to wybor z menu)\n".
  "  -h          : Ten komunikat pomocy\n".
  "  -v          : Tryb gadatliwy\n".
  "  -s          : Wyswietla liste wspieranych jezykow i konczy dzialanie\n".
  "  -r          : Usuwa wszystkie ustawienia\n".
  "  -N          : Nie forkuje set-language-env (do uzytku wewnetrznego)\n".
  "  -c          : Nie uzywa natywnego zestawu znakow (do uzytku wewnetrz.)\n".
  "  -C          : Uzywa natywnego zestawu znakow (do uzytku wewnetrznego)\n".
  "  -E          : Ustawienia w katalogu /etc/skel (tylko uzytkownik root)\n\000" .
# msgstr2 (in Native Character Set)
  "Uycie: set-language-env [opcje]\n".
  "  -l jzyk    : Okrela jzyk (jeeli nie podano, to wybr z menu)\n".
  "  -h          : Ten komunikat pomocy\n".
  "  -v          : Tryb gadatliwy\n".
  "  -s          : Wywietla list wspieranych jzykw i koczy dziaanie\n".
  "  -r          : Usuwa wszystkie ustawienia\n".
  "  -N          : Nie forkuje set-language-env (do uytku wewntrznego)\n".
  "  -c          : Nie uywa natywnego zestawu znakw (do uytku wewntrz.)\n".
  "  -C          : Uywa natywnego zestawu znakw (do uytku wewntrznego)\n".
  "  -E          : Ustawienia w katalogu /etc/skel (tylko uytkownik root)\n" ,

# msgid
  "Install the following locales.\n" =>
  "Prosze zainstalowac nastepujace definicje ustawien regionalnych.\n\000".
  "Prosz zainstalowa nastpujce definicje ustawie regionalnych.\n" ,

# msgid
  "(Edit /etc/locale.gen and invoke locale-gen)\n" =>
  "(Wyedytuj /etc/locale.gen, a nastepnie uruchom locale-gen)\n\000".
  "(Wyedytuj /etc/locale.gen, a nastpnie uruchom locale-gen)\n" ,

# msgid
  "" =>
  "\000".
  ""

);

$yes_upper = "T";
$yes_lower = "t";
$no_upper  = "N";
$no_lower  = "n";
$need_locale = 'pl_PL(pl_PL!ISO-8859-2) pl_PL.UTF-8(pl_PL.UTF-8!UTF-8)';
